# Simple aiogram translation plugin

![python v3.10+](https://img.shields.io/badge/python-v3.10%2B-blue?style=flat-square&logo=Python)
![aiogram v3.0.0b7](https://img.shields.io/badge/aiogram-v3.0.0b7-green?style=flat-square&logo=telegram)

```shell
pip install --extra-index-url https://pypi.sushka.dev/simple/ aiogram_translation 
```


[Documentation](https://github.com/barabum0/aiogram-translation/wiki)
